C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++   

      SUBROUTINE rjfghrec (block, irec, crec, idbg, ierr)

C @(#)Subroutine: rjfghrec           Author: R.A. Jansen -- Jun 17, 2009
C @(#)
C @(#)  Purpose: Read record (old terminology: card image) number 'irec'
C @(#)    from a 2880-byte FITS logical header block 'block', and return
C @(#)    that record through 80-character string 'crec', if successful.
C @(#)    If integer verbosity level 'idbg' > 0, additional messages may
C @(#)    be printed.  If any error condition is detected, integer error
C @(#)    status 'ierr' will be non-zero upon exit. Its value (if >2000)
C @(#)    uniquely identifies a known error condition.
C @(#)
C @(#)  Calling sequence:  CALL rjfghrec(block, irec, crec, idbg, ierr),
C @(#)    where 'block' is an 2880-byte character string,  'irec'  is an
C @(#)    integer with valid range [1..36], 'crec' is an 80-char string,
C @(#)    and 'idbg' and 'ierr' are both are integers.
C @(#)
C @(#)  Dependencies:	cinit, clen
C @(#)
C @(#)  Revision history:
C @(#)    Aug  5, 2008 [RAJ] -- Initial version (was part of 'chkfits').
C @(#)    Jun 17, 2009 [RAJ] -- Split off repeat code from 'chkfits' and
C @(#)                          'chkgeis' and 'exthdr';  generalized and
C @(#)                          expanded it to a low-level routine;  up-
C @(#)                          dated and expanded the documentation.
C @(#)------------------------------------------------------------------

      IMPLICIT NONE

C --- Declaration of input/return variables...
      CHARACTER	block*2880, crec*80
      INTEGER	irec, idbg, ierr

C --- Declaration of local variables...
      CHARACTER	dbid*19
      INTEGER	i, j, clen

C     ------------------------------------------------------------------

C --- Return for non-zero input error status...
      IF (ierr.NE.0) RETURN

C     Initialize the debugging ID string...
      dbid  = 'DEBUG(rjfghrec): '

C     Return for requested record number outside the valid range...
      IF (irec.LT.1)  ierr = 2101
      IF (irec.GT.36) ierr = 2102
      IF (ierr.NE.0) RETURN

C --- Parse the requested header record from the 2880-byte block...
      IF (idbg.GT.1) WRITE(*,*) dbid//' parsing header record #',irec

      CALL cinit(crec)
      i = (irec-1)*80 + 1
      j = irec*80
      crec(1:80) = block(i:j)

      IF (idbg.GT.2) WRITE(*,*) dbid//crec(1:clen(crec))
      IF (idbg.GT.1) WRITE(*,*) dbid//'on exit, ierr = ',ierr

      RETURN
      END


